"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PasswordInput = exports.calculatePasswordScore = void 0;

var _fastPasswordEntropy = _interopRequireDefault(require("fast-password-entropy"));

var _react = _interopRequireWildcard(require("react"));

var _ThemeContext = require("./HOC/ThemeContext");

var _themes = require("../utils/themes");

var _ = require(".");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var calculatePasswordScore = function calculatePasswordScore(password) {
  var entropyFactor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.01;
  return Math.min(((0, _fastPasswordEntropy["default"])(password) * entropyFactor).toFixed(2), 1);
};

exports.calculatePasswordScore = calculatePasswordScore;
var STATE = {
  DEFAULT: 'default',
  ERROR: 'error',
  INSECURE: 'insecure',
  WEAK: 'weak',
  STRONG: 'strong'
};

var PasswordInput = function PasswordInput(props) {
  var context = props.context,
      passwordFeedbacks = props.passwordFeedbacks,
      entropyFactor = props.entropyFactor,
      error = props.error,
      minLength = props.minLength,
      maxLength = props.maxLength,
      minStrongScore = props.minStrongScore,
      isPasswordRepeat = props.isPasswordRepeat,
      repeatPassword = props.repeatPassword,
      skin = props.skin,
      state = props.state,
      theme = props.theme,
      themeOverrides = props.themeOverrides,
      tooltip = props.tooltip,
      rest = _objectWithoutProperties(props, ["context", "passwordFeedbacks", "entropyFactor", "error", "minLength", "maxLength", "minStrongScore", "isPasswordRepeat", "repeatPassword", "skin", "state", "theme", "themeOverrides", "tooltip"]); // Theme


  var themeContext = context || (0, _react.useContext)(_ThemeContext.ThemeContext);
  var composedTheme = (0, _themes.composeTheme)((0, _themes.addThemeId)(theme || themeContext.theme, props.themeId), (0, _themes.addThemeId)(props.themeOverrides, props.themeId), themeContext.ROOT_THEME_API); // Skin

  var PasswordInputSkin = skin || themeContext.skins[_.IDENTIFIERS.PASSWORD_INPUT]; // Logic

  var dynamicState = PasswordInput.STATE.DEFAULT;
  var passwordFeedback = null;
  var password = props.value;
  var score = calculatePasswordScore(password, entropyFactor);
  var isValidPassword = password.length >= minLength && password.length <= maxLength;
  var isNotEmpty = password.length > 0;

  if (error) {
    dynamicState = PasswordInput.STATE.ERROR;
    passwordFeedback = error;
  } else if (tooltip) {
    passwordFeedback = tooltip;
  } else if (isPasswordRepeat) {
    if (repeatPassword === props.value) {
      dynamicState = PasswordInput.STATE.DEFAULT;
      passwordFeedback = null;
    } else {
      dynamicState = PasswordInput.STATE.ERROR;
      passwordFeedback = passwordFeedbacks.noMatch;
    }
  } else if (isValidPassword) {
    if (score < minStrongScore) {
      dynamicState = PasswordInput.STATE.WEAK;
      passwordFeedback = passwordFeedbacks[PasswordInput.STATE.WEAK];
    } else {
      dynamicState = PasswordInput.STATE.STRONG;
      passwordFeedback = passwordFeedbacks[PasswordInput.STATE.STRONG];
    }
  } else if (isNotEmpty) {
    dynamicState = PasswordInput.STATE.INSECURE;
    passwordFeedback = passwordFeedbacks[PasswordInput.STATE.INSECURE];
  }

  return (
    /*#__PURE__*/
    _react["default"].createElement(PasswordInputSkin, _extends({
      error: error,
      theme: composedTheme,
      score: score,
      state: state || dynamicState,
      tooltip: passwordFeedback
    }, rest))
  );
}; // Static Properties


exports.PasswordInput = PasswordInput;
PasswordInput.STATE = STATE;
PasswordInput.displayName = 'PasswordInput';
PasswordInput.defaultProps = {
  debounceDelay: 1000,
  entropyFactor: 0.01,
  passwordFeedbacks: {
    insecure: 'insecure',
    weak: 'weak',
    strong: 'strong',
    noMatch: "doesn't match"
  },
  isPasswordRepeat: false,
  isTooltipOpen: false,
  isShowingTooltipOnFocus: true,
  isShowingTooltipOnHover: true,
  minLength: 10,
  maxLength: 255,
  minStrongScore: 0.75,
  readOnly: false,
  theme: null,
  themeId: _.IDENTIFIERS.PASSWORD_INPUT,
  themeOverrides: {},
  useDebounce: true,
  value: ''
};
//# sourceMappingURL=PasswordInput.js.map