"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AutocompleteSkin = void 0;

var _some2 = _interopRequireDefault(require("lodash/some"));

var _slice2 = _interopRequireDefault(require("lodash/slice"));

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _FormField = require("../../components/FormField");

var _Options = require("../../components/Options");

var _OptionsSkin = require("./OptionsSkin");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

// components
// skins
var AutocompleteSkin = function AutocompleteSkin(props) {
  var theme = props.theme[props.themeId];
  var filteredAndLimitedOptions = (0, _slice2["default"])(props.filteredOptions, 0, props.maxVisibleOptions); // show placeholder only if no maximum selections declared or maximum not reached

  var canMoreOptionsBeSelected = props.selectedOptions.length < props.maxSelections;
  var placeholder = !props.maxSelections || canMoreOptionsBeSelected ? props.placeholder : '';

  var renderSelectedOptions = function renderSelectedOptions() {
    // check if the user passed a renderSelections function
    if (props.selectedOptions && props.renderSelections) {
      // call custom renderSelections function
      return props.renderSelections(props.getSelectionProps);
    }

    if (props.selectedOptions && !props.renderSelections) {
      // render default skin
      return props.selectedOptions.map(function (selectedOption, index) {
        return (
          /*#__PURE__*/
          _react["default"].createElement("span", {
            className: theme.selectedWordBox,
            key: index
          },
          /*#__PURE__*/
          _react["default"].createElement("span", {
            className: theme.selectedWordValue
          }, selectedOption,
          /*#__PURE__*/
          _react["default"].createElement("span", {
            role: "presentation",
            "aria-hidden": true,
            className: theme.selectedWordRemoveButton,
            onClick: props.removeOption.bind(null, index)
          }, "\xD7")))
        );
      });
    }

    return null;
  };

  var selectedOptionsCount = props.selectedOptions.length;
  var hasSelectedRequiredNumberOfOptions = props.requiredSelections.length === 0 || (0, _some2["default"])(props.requiredSelections, function (requiredCount) {
    return selectedOptionsCount === requiredCount;
  });
  var error = hasSelectedRequiredNumberOfOptions ? props.error : null;
  return (
    /*#__PURE__*/
    _react["default"].createElement("div", {
      "aria-hidden": true,
      className: (0, _classnames["default"])([props.className, theme.autocompleteWrapper]),
      onClick: props.handleAutocompleteClick,
      ref: props.rootRef,
      role: "presentation"
    }, props.requiredSelections.length > 0 && props.requiredSelectionsInfo != null &&
    /*#__PURE__*/
    _react["default"].createElement("div", {
      className: theme.requiredWordsInfo
    }, props.requiredSelectionsInfo(props.requiredSelections, selectedOptionsCount)),
    /*#__PURE__*/
    _react["default"].createElement(_FormField.FormField, {
      error: error,
      formFieldRef: props.inputRef,
      label: props.label,
      isErrorHidden: props.isOpen,
      render: function render(setFormFieldRef) {
        return (
          /*#__PURE__*/
          _react["default"].createElement("div", {
            className: (0, _classnames["default"])([theme.autocompleteContent, props.isOpen ? theme.opened : null, props.selectedOptions.length ? theme.hasSelectedWords : null, error ? theme.errored : null]),
            ref: props.suggestionsRef
          },
          /*#__PURE__*/
          _react["default"].createElement("div", {
            className: theme.selectedWords
          }, renderSelectedOptions(),
          /*#__PURE__*/
          _react["default"].createElement("input", {
            ref: setFormFieldRef,
            placeholder: placeholder,
            value: props.inputValue,
            onChange: props.handleInputChange,
            onKeyDown: props.onKeyDown
          })))
        );
      }
    }),
    /*#__PURE__*/
    _react["default"].createElement(_Options.Options, {
      isOpen: props.isOpen,
      isOpeningUpward: props.isOpeningUpward,
      noResults: !props.filteredOptions.length,
      onChange: props.handleChange,
      options: filteredAndLimitedOptions,
      optionsRef: props.optionsRef,
      optionsMaxHeight: props.optionsMaxHeight,
      render: props.renderOptions,
      resetOnClose: true,
      selectedOptions: props.selectedOptions,
      skin: _OptionsSkin.OptionsSkin,
      targetRef: props.suggestionsRef,
      toggleMouseLocation: props.toggleMouseLocation,
      toggleOpen: props.toggleOpen,
      optionHeight: props.optionHeight
    }))
  );
};

exports.AutocompleteSkin = AutocompleteSkin;
//# sourceMappingURL=AutocompleteSkin.js.map